Enum wlink::error::AbstractcsCmdErr
source · pub enum AbstractcsCmdErr {
Busy,
NotSupported,
Exception,
HaltOrResume,
Bus,
Parity,
Other,
}Variants
Busy
Write to the command, abstractcs and abstractauto registers, or read/write to the data and progbuf registers when the abstract command is executed.
NotSupported
The current abstract command is not supported
Exception
error occurs when the abstract command is executed.
HaltOrResume
the hart wasn’t in the required state (running/halted), or unavailable
Bus
bus error (e.g. alignment, access size, or timeout)
Parity
Parity bit error during communication (WCH’s extension)
Other
The command failed for another reason.